@@ -361,12 +361,12 @@ class DublinCore (object):
         lit = writer.literal
         # uri = writer.uri
 
-        lit ('dcterms:title',      self.title)
-        lit ('dcterms:source',     self.source)
+        lit ('dc:title',      self.title)
 
         for language in self.languages:
-            lit ('dcterms:language', language.id, 'dcterms:RFC4646')
+            lit ('dc:language', language.id, 'dcterms:RFC4646')
 
+        lit ('dcterms:source',     self.source)
         lit ('dcterms:modified',
              datetime.datetime.now (gg.UTC ()).isoformat (),
              'dcterms:W3CDTF')
@@ -381,9 +381,6 @@ class DublinCore (object):
         e = ElementMaker ()
 
         head = e.head (
-            e.link (rel = "schema.DCTERMS", href = str (NS.dcterms)),
-            e.link (rel = "schema.MARCREL", href = str (NS.marcrel)),
-            profile = "http://dublincore.org/documents/2008/08/04/dc-html/",
             *w.metadata
             )
 
@@ -517,18 +514,18 @@ class GutenbergDublinCore (DublinCore):
         lit = writer.literal
         uri = writer.uri
 
-        lit('dcterms:publisher',  self.publisher)
-        lit('dcterms:rights',     self.rights)
+        lit('dc:publisher',  self.publisher)
+        lit('dc:rights',     self.rights)
         uri('dcterms:isFormatOf', self.is_format_of)
 
         for author in self.authors:
             if author.marcrel == 'aut' or author.marcrel == 'cre':
-                lit('dcterms:creator', author.name_and_dates)
+                lit('dc:creator', author.name_and_dates)
             else:
                 lit('marcrel:' + author.marcrel, author.name_and_dates)
 
         for subject in self.subjects:
-            lit('dcterms:subject', subject.subject, 'dcterms:LCSH')
+            lit('dc:subject', subject.subject, 'dcterms:LCSH')
 
         if self.release_date:
             lit('dcterms:created', self.release_date.isoformat(),
@@ -686,6 +683,7 @@ class GutenbergDublinCore (DublinCore):
             if m:
                 self.project_gutenberg_id = int (m.group (1))
                 self.is_format_of = str (NS.ebook) + str (self.project_gutenberg_id)
+                self.canonical_url = re.sub(r'^http:', 'https:', self.is_format_of) + '/'
 
 
         def handle_languages (self, dummy_prefix, text):
